@@ -773,7 +773,7 @@ gnome_vfs_get_volume_free_space (const GnomeVFSURI *vfs_uri,
        	int statfs_result;
 	const char *path, *scheme;
 	char *unescaped_path;
-	GnomeVFSResult ret;
+
 #if HAVE_STATVFS
 	struct statvfs statfs_buffer;
 #else
@@ -787,8 +787,6 @@ gnome_vfs_get_volume_free_space (const GnomeVFSURI *vfs_uri,
 		return GNOME_VFS_ERROR_NOT_SUPPORTED;
 	}
 
-	unescaped_path = gnome_vfs_unescape_string (path, G_DIR_SEPARATOR_S);
-	
 	scheme = gnome_vfs_uri_get_scheme (vfs_uri);
 	
         /* We only handle the file scheme for now */
@@ -796,27 +794,26 @@ gnome_vfs_get_volume_free_space (const GnomeVFSURI *vfs_uri,
 		return GNOME_VFS_ERROR_NOT_SUPPORTED;
 	}
 
+	unescaped_path = gnome_vfs_unescape_string (path, G_DIR_SEPARATOR_S);
+	
 #if HAVE_STATVFS
 	statfs_result = statvfs (unescaped_path, &statfs_buffer);
 #else
 	statfs_result = statfs (unescaped_path, &statfs_buffer);   
 #endif  
 
-	if (statfs_result == 0) {
-		ret = GNOME_VFS_OK;
-	} else {
-		ret = gnome_vfs_result_from_errno ();
+	g_free (unescaped_path);
+
+	if (statfs_result != 0) {
+		return gnome_vfs_result_from_errno ();
 	}
 	
-	g_return_val_if_fail (statfs_result == 0, FALSE);
 	block_size = statfs_buffer.f_bsize; 
 	free_blocks = statfs_buffer.f_bavail;
 
 	*size = block_size * free_blocks;
-
-	g_free (unescaped_path);
 	
-	return ret;
+	return GNOME_VFS_OK;
 }
 
 /**
